@@ -106,6 +106,7 @@
 #include "convert/source-fs.h"
 #include "crypto/crc32c.h"
 #include "common/fsfeatures.h"
+#include "common/device-scan.h"
 #include "common/box.h"
 #include "common/open-utils.h"
 
@@ -396,6 +397,7 @@ static int migrate_one_reserved_range(struct btrfs_trans_handle *trans,
 		}
 		eb->start = key.objectid;
 		eb->len = key.offset;
+		eb->fs_info = root->fs_info;
 
 		/* Write the data */
 		ret = write_and_map_eb(root->fs_info, eb);
@@ -1189,6 +1191,8 @@ static int do_convert(const char *devname, u32 convert_flags, u32 nodesize,
 
 	if (convert_flags & CONVERT_FLAG_COPY_FSID) {
 		uuid_unparse(cctx.fs_uuid, mkfs_cfg.fs_uuid);
+		if (!test_uuid_unique(mkfs_cfg.fs_uuid))
+			warning("non-unique UUID (copy): %s", mkfs_cfg.fs_uuid);
 	} else if (fsid[0] == 0) {
 		uuid_t uuid;
 
@@ -1196,6 +1200,8 @@ static int do_convert(const char *devname, u32 convert_flags, u32 nodesize,
 		uuid_unparse(uuid, mkfs_cfg.fs_uuid);
 	} else {
 		memcpy(mkfs_cfg.fs_uuid, fsid, BTRFS_UUID_UNPARSED_SIZE);
+		if (!test_uuid_unique(mkfs_cfg.fs_uuid))
+			warning("non-unique UUID (user set): %s", mkfs_cfg.fs_uuid);
 	}
 
 	printf("Source filesystem:\n");
